#==============================================================================

# Copyright (c) 2016-11-21, Laurenz Wiskott, http://www.ini.rub.de/PEOPLE/wiskott/
# License: BSD 2-Clause, https://opensource.org/licenses/BSD-2-Clause, see the end

#==============================================================================

from gaussian import Gaussian

class GaussianCluster(Gaussian):

    LINESTYLE_DEFAULT = '--'
    
    def __init__(self, dim=Gaussian.DIM_DEFAULT, mean_std=Gaussian.MEAN_STD_DEFAULT,
                 mean='random', trafo='random', num=Gaussian.NUM_DEFAULT,
                 color=Gaussian.COLOR_DEFAULT, linestyle=LINESTYLE_DEFAULT):
        """Initialize cluster from Gaussian with either given or random mean and trafo.

        num (int or np.array): number of data points per cluster

        For further arguments, see Gaussian.__INIT__().
        """

        Gaussian.__init__(self, dim=dim, mean_std=mean_std, mean=mean, trafo=trafo, num=num, color=color, linestyle=linestyle)
        
        self.points = self.sample_points(num=num)


    def point(self, point_idx):

        return self.points[point_idx]
            

    def ax_plot(self, ax, axes=Gaussian.AXES_DEFAULT, linewidth=Gaussian.LINEWIDTH_DEFAULT):

        Gaussian.ax_plot(self, ax, axes, linewidth=linewidth)

        ax.scatter(self.points[:,axes[0]], self.points[:,axes[1]], s=self.POINT_SIZE, color=self.color)


#==============================================================================
#==============================================================================

# BSD 2-Clause License

# All rights reserved.

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:

# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.

# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

#==============================================================================

